@@ -9,14 +9,13 @@
 
 #include "session.h"
 #include <QStringList>
-#include <QUrl>
 #include <QProcess>
 
 class PythonSession : public Cantor::Session
 {
   Q_OBJECT
   public:
-    PythonSession(Cantor::Backend* backend);
+    PythonSession(Cantor::Backend*);
     ~PythonSession() override;
 
     void login() override;
@@ -27,21 +26,21 @@ class PythonSession : public Cantor::Session
     Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete, bool internal = false) override;
     Cantor::CompletionObject* completionFor(const QString& command, int index=-1) override;
     QSyntaxHighlighter* syntaxHighlighter(QObject* parent) override;
-    void setWorksheetPath(const QString& path) override;
+    void setWorksheetPath(const QString&) override;
 
     QString plotFilePrefixPath();
     int& plotFileCounter();
 
   private:
-    QProcess* m_process;
+    QProcess* m_process{nullptr};
     QString m_worksheetPath;
     QString m_output;
     QString m_plotFilePrefixPath;
-    int m_plotFileCounter;
+    int m_plotFileCounter{0};
 
   private Q_SLOT:
     void readOutput();
-    void reportServerProcessError(QProcess::ProcessError serverError);
+    void reportServerProcessError(QProcess::ProcessError);
 
   private:
     void runFirstExpression() override;
