@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+*/
 
 #include "imageresult.h"
 using namespace Cantor;
@@ -174,11 +159,9 @@ void ImageResult::saveAdditionalData(KZip* archive)
 
 void ImageResult::save(const QString& filename)
 {
-    //load into memory and let Qt save it, instead of just copying d->url
-    //to give possibility to convert file format
-    QImage img=data().value<QImage>();
-
-    img.save(filename);
+    bool rc = d->img.save(filename);
+    if (!rc)
+        qDebug()<<"saving to " << filename << " failed.";
 }
 
 QSize Cantor::ImageResult::displaySize()
